==> dwcm-0.7.tar.gz: dwcm-0.7/setup.py <==
import json
import os
from setuptools import setup




setup(
    name='dwcm',
    version='0.7',
    author="Sunny CM <cm.for.dev@gmail.com>",
    packages=['dwcm'],
    include_package_data=True,
    license="MIT",
    description="Word Cloud",
    install_requires=['jupyter_dash','dash_html_components','dash'],
    url = 'https://github.com/Cmccm123', 
    download_url = 'https://github.com/Cmccm123/DWCM/archive/refs/tags/D3.tar.gz', 
    keywords = ['D3', 'D3.js', 'Word Cloud','DASH','data visualization'],
    data_files=[('js', ['Dwcm/dwcm.min.js','Dwcm/output.js']),
                ('json', ['Dwcm/metadata.json','Dwcm/package-info.json']),
                ('MAP', ['Dwcm/dwcm.min.js.map','Dwcm/output.js.map'])],
    classifiers = [
        'Framework :: Dash',
        'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],    
)

==> dwcm-0.7.1.tar.gz: dwcm-0.7.1/setup.py <==
import json
import os
from setuptools import setup




setup(
    name='dwcm',
    version='0.7.1',
    author="Sunny CM <cm.for.dev@gmail.com>",
    packages=['dwcm'],
    include_package_data=True,
    license="MIT",
    description="Word Cloud",
    install_requires=['jupyter_dash','dash_html_components','dash'],
    url = 'https://github.com/Cmccm123', 
    download_url = 'https://github.com/Cmccm123/DWCM/archive/refs/tags/D3.tar.gz', 
    keywords = ['D3', 'D3.js', 'Word Cloud','DASH','data visualization'],
    data_files=[('js', ['dwcm/dwcm.min.js','dwcm/output.js']),
                ('json', ['dwcm/metadata.json','dwcm/package-info.json']),
                ('MAP', ['dwcm/dwcm.min.js.map','dwcm/output.js.map'])],
    classifiers = [
        'Framework :: Dash',
        'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],    
)
